/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: MDBBeanHelper.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.helper.bean.mdb;

import static org.ow2.easybeans.asm.Opcodes.ACC_PUBLIC;
import static org.ow2.easybeans.deployment.annotations.helper.ResolverHelper.getMethod;

import org.ow2.easybeans.deployment.annotations.exceptions.ResolverException;
import org.ow2.easybeans.deployment.metadata.ejbjar.EasyBeansEjbJarClassMetadata;
import org.ow2.easybeans.deployment.metadata.ejbjar.EasyBeansEjbJarMethodMetadata;
import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * Helper class for MDB.
 * @author Florent Benoit
 */
public final class MDBBeanHelper {

    /**
     * MDB lifecylce Methods that a bean can defined.
     */
    private static final String MDB_METHODS = "ejbCreate()/ejbRemove() methods";


    /**
     * ejbRemove() method.
     */
    private static final JMethod EJBCREATE_METHOD = new JMethod(ACC_PUBLIC, "ejbCreate",
            "()V", null, new String[] {"javax/ejb/CreateException"});

    /**
     * ejbRemove() method.
     */
    private static final JMethod EJBREMOVE_METHOD = new JMethod(ACC_PUBLIC, "ejbRemove",
            "()V", null, new String[] {"javax/ejb/EJBException", "java/rmi/RemoteException"});

    /**
     * Utility class.
     */
    private MDBBeanHelper() {

    }

    /**
     * Apply all helper.
     * @param mdbBean MDB bean to analyze
     * @throws ResolverException if there is a failure in a resolver
     */
    public static void resolve(final EasyBeansEjbJarClassMetadata mdbBean) throws ResolverException {

        // ejbCreate() method
        EasyBeansEjbJarMethodMetadata ejbCreateMethod = getMethod(mdbBean, EJBCREATE_METHOD, true, MDB_METHODS, false);
        if (ejbCreateMethod != null) {
            ejbCreateMethod.setPostConstruct(true);
            if (!mdbBean.getPostConstructMethodsMetadata().contains(ejbCreateMethod)) {
                mdbBean.addPostConstructMethodMetadata(ejbCreateMethod);
            }
        }

        // ejbRemove() method
        EasyBeansEjbJarMethodMetadata ejbRemoveMethod = getMethod(mdbBean, EJBREMOVE_METHOD, true, MDB_METHODS, false);
        if (ejbRemoveMethod != null) {
            ejbRemoveMethod.setPreDestroy(true);
            if (!mdbBean.getPreDestroyMethodsMetadata().contains(ejbRemoveMethod)) {
                mdbBean.addPreDestroyMethodMetadata(ejbRemoveMethod);
            }
        }

    }

}
